<?php

namespace Schaffen\Gef\Services;

use App\Http\Utils\SCHArray;
use Schaffen\Gef\Models\ProdutoFrota;
use Schaffen\Gef\Repositories\ProdutoFrotaRepository;
use Schaffen\Gef\Validators\ProdutoFrotaValidator;
use Prettus\Validator\Exceptions\ValidatorException;
use App\Models\Produto\ProdutoVariedadeEmbalagem;

class ProdutoFrotaService
{

   private $repository;
   private $validator;

    public function __construct(ProdutoFrotaRepository $repository, ProdutoFrotaValidator $validator)
    {
       $this->repository = $repository;
       $this->validator = $validator;
    }

   public function updateOrCreate($data, $codigo = null)
   {
      try {

         $produto = ProdutoVariedadeEmbalagem::with('variedade')->where('pve_codigo',$data['produto'])->first();
         $data['variedade_embalagem'] = $produto->pve_codigo;
         $data['produto'] = $produto->variedade->prv_fk_pro_codigo;

         $attrib = ['prfr_codigo' => $codigo];

         $validator_rules = is_numeric($codigo) ? ProdutoFrotaValidator::RULE_UPDATE : ProdutoFrotaValidator::RULE_CREATE;
         $this->validator->with($data)->passesOrFail($validator_rules);
         $this->repository->setPresenter("Schaffen\\Gef\\Presenters\\ProdutoFrotaPresenter");


         $new_data['fk_pro_codigo'] = $data['produto'];
         $new_data['fk_cag_codigo'] = $data['categoria'];
         $new_data['fk_pve_codigo'] = $data['variedade_embalagem'];

         $data = SCHArray::addPrefix(ProdutoFrota::$prefix, $new_data);
         $produto_frota = $this->repository->updateOrCreate($attrib, $data);

         $response = [
            'status' => true,
            'errors' => '',
            'message' => 'Produto(Frota) gravado.',
            'data' => $produto_frota['data'],
            'http_code' => '200'
         ];


         return $response;

      } catch (ValidatorException $e) {
         return $response = [
            'status' => false,
            'errors' => $e->getMessageBag(),
            'message' => 'Não foi possível gravar o Produto(Frota)',
            'data' => null,
            'http_code' => '400'
         ];
      }
   }
}
